@@ -9,17 +9,18 @@ from napoleontoolbox.file_saver import dropbox_file_saver
 import json
 
 class SignalParalleLauncher():
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', triggers = [True], transaction_costs = [True], signal_idiosyncratic_paramaters=[None]):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', triggers = [True], transaction_costs = [True], normalizations = [False], signal_idiosyncratic_paramaters=[None]):
         self.args = []
         self.counter = 1
         self.seed = 0
         for trigger in triggers:
             for transaction_cost in transaction_costs:
-                for signal_type, params  in signal_idiosyncratic_paramaters.items():
-                    for param in params:
-                        self.args.append((self,self.seed,trigger,signal_type, json.dumps(param, sort_keys=True), transaction_cost))
-                        self.counter = self.counter + 1
-            self.args.sort()
+                for normalization in normalizations:
+                    for signal_type, params  in signal_idiosyncratic_paramaters.items():
+                        for param in params:
+                            self.args.append((self,self.seed,trigger,signal_type, json.dumps(param, sort_keys=True), transaction_cost, normalization))
+                            self.counter = self.counter + 1
+        self.args.sort()
         self.local_root_directory = local_root_directory
         self.user = user
         self.db_path_suffix = db_path_suffix
