@@ -5,9 +5,7 @@ from abc import ABC, abstractmethod
 
 import pandas as pd
 
-import matplotlib.pyplot as plt
 import numpy as np
-import torch.nn.functional as F
 
 from napoleontoolbox.neural_net import roll_multi_layer_lstm
 from napoleontoolbox.file_saver import dropbox_file_saver
@@ -24,14 +22,16 @@ import torch.nn as nn
 
 
 class AbstractRunner(ABC):
-    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision = False):
+    def __init__(self, starting_date = None, running_date = None, drop_token=None, dropbox_backup = True, save_model=False, supervision_npy_file_suffix='_supervision.npy', macro_supervision_npy_file_suffix='_macro_supervision.npy', features_saving_suffix='_features.npy', features_names_saving_suffix='_features_names.npy', returns_pkl_file_name='returns.pkl', shortcut_features_pkl_file_name='shortcut.pkl', local_root_directory='../data/', user = 'napoleon', n_start = 252, maximum_precision = False, shortcut_features = False):
         super().__init__()
         self.supervision_npy_file_suffix=supervision_npy_file_suffix
         self.macro_supervision_npy_file_suffix=macro_supervision_npy_file_suffix
         self.features_saving_suffix=features_saving_suffix
         self.features_names_saving_suffix=features_names_saving_suffix
         self.returns_pkl_file_name=returns_pkl_file_name
+        self.shortcut_features_pkl_file_name = shortcut_features_pkl_file_name
         self.local_root_directory=local_root_directory
+        self.shortcut_features = shortcut_features
         self.user=user
         self.n_start = n_start
         self.dropbox_backup = dropbox_backup
