@@ -94,7 +94,7 @@ class ParallelRunResultAnalyzer():
                     params = json.loads(run_json_string)
                     #salty = hashlib.sha256(run_json_string)
                     salty =str(int(hashlib.sha1(run_json_string.encode('utf-8')).hexdigest(), 16) % (10 ** 8))
-                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+salty
+                    renaming_dictionary[col] = params['signal_type']+str(params['transaction_costs'])+str(params['normalization'])+salty
 
             results_df = results_df.rename(columns=renaming_dictionary, errors="raise")
         return results_df
