@@ -45,7 +45,7 @@ class SimpleSignalRunner(AbstractRunner):
         check_run_existence = saver.checkRunExistence(saving_key)
         if check_run_existence:
             return
-        if normalization and signal_generator.is_signal_continuum(signal_type):
+        if normalization and not signal_generator.is_signal_continuum(signal_type):
             return
         print('Launching computation with parameters : '+saving_key)
         hourly_df = pd.read_pickle(self.local_root_directory+self.hourly_pkl_file_name)
